local AddName, Ns = ...
local L = Ns.L

------------------------------
--		Options Equates		--
------------------------------
local Both, Enhanced, Base, World, Realm, Equipped, Max, Level, Honor, Percentage, Rating = 3, 1, 2, 1, 2, 1, 2, 1, 2, 1, 2

----------------------------------
--		Text Return Formats		--
----------------------------------
local Double_Rating_Format = { "%.0f", "%.0f", "%.0f/%.0f", }
local Base_Casting_Format = { "%.2f", "%.2f", "%.2f/%.2f", }

----------------------
--		Misc		--
----------------------

-- Target Speed
function Ns.FunctionList.TargetSpeed(HUD, data, options, ...)

	local speedColor = ""
	local targetSpeed = GetUnitSpeed("target") / 7 * 100
	
	if targetSpeed == 0 or targetSpeed == 100 then speedColor = ""
	elseif targetSpeed < 100 then speedColor = "|cffC41E3A"
	elseif targetSpeed > 100 then speedColor = "|cff71FFC9" end

	HUD:UpdateText(data, speedColor .. string.format("%d%%", ("%.0f"):format(targetSpeed)))
end
------------------------------------------------

-- Durability
function Ns.FunctionList.Durability(HUD, data, options, ...)
	local Durability, Current, Full, Percent
	local LowestCurrent, LowestFull, t1, t2, t3 = 500, 0, 0, 0, 100
	for i=1,19 do
		Current, Full = GetInventoryItemDurability(i)
		if Current and Full then
			Percent = floor(100*Current/Full + 0.5)
			if (Percent < t3) then
				t3 = Percent
			end
			if (Current < LowestCurrent) then
				LowestCurrent = Current
				LowestFull = Full
			end
			t1 = t1 + Current
			t2 = t2 + Full
		end
	end
	if t2 == 0 then
		Durability = "N/A"
	else
		Durability = floor(t1 * 100 / t2)
	end
	local Text = ""
	if type(Durability) == "number" then
		if Durability > 50 then
			Text = string.format("|cff%2xff00", ((Durability > 50) and (255 - 2.55*Durability) or (2.55*Durability)), Durability) .. Text
		else
			Text = string.format("|cffff%2x00", (2.55*Durability), Durability) .. Text
		end
		Text = Text..Durability.."%"
	end
	
	HUD:UpdateText(data, Text)
end
------------------------------------------------

-- Repair cost
function Ns.FunctionList.RepairCost(HUD, data, options, ...)

	local totalCost = 0

	for slotName, slotID in pairs(Enum.InventoryType) do
		local itemDurability
		local repairCost
	
		itemDurability = C_TooltipInfo.GetInventoryItem("player", slotID)
		
		if itemDurability then TooltipUtil.SurfaceArgs(itemDurability) ; repairCost = itemDurability.repairCost end
		if repairCost and repairCost > 0 then totalCost = totalCost + repairCost end
	end	

	HUD:UpdateText(data, GetCoinTextureString(totalCost))
end
------------------------------------------------

-- Item Level
function Ns.FunctionList.ItemLevel(HUD, data, options, ...)

	local EB, percentStat, ratingStat = options.Equipped_Overall
	local overall, equipped, pvp = GetAverageItemLevel()
	local returnText, decimals
	
	if options.Decimals_iLVL == 0 then decimals = "%.0f"
	elseif options.Decimals_iLVL == 1 then decimals = "%.1f"
	elseif options.Decimals_iLVL == 2 then decimals = "%.2f"
	else decimals = "%.3f" end	

	if Ns.Band(EB, Equipped) then returnText = (decimals):format(equipped) end
	if Ns.Band(EB, Max) then returnText = (decimals):format(overall) end
	if Ns.Band(EB, Both) then returnText = (decimals):format(equipped) .. "/" .. (decimals):format(overall) end
	if returnText == nil then returnText = 0 end	

	HUD:UpdateText(data, returnText)
end
------------------------------------------------

-- PvP iLvl
function Ns.FunctionList.PvPiLvl(HUD, data, options, ...)

	local pvp = select(3, GetAverageItemLevel())
	local decimals

	if options.Decimals_pvpiLVL == 0 then decimals = "%.0f"
	elseif options.Decimals_pvpiLVL == 1 then decimals = "%.1f"
	elseif options.Decimals_pvpiLVL == 2 then decimals = "%.2f"
	else decimals = "%.3f" end		
	
	HUD:UpdateText(data, (decimals):format(pvp))
end
------------------------------------------------

-- Renown
function Ns.FunctionList.Renown(HUD, data, options, ...)

	local dragonscale = C_CurrencyInfo.GetCurrencyInfo(2021)
	local tuskarr = C_CurrencyInfo.GetCurrencyInfo(2087)
	local centaur = C_CurrencyInfo.GetCurrencyInfo(2002)
	local valdrakken = C_CurrencyInfo.GetCurrencyInfo(2088)

	if dragonscale.name and tonumber(dragonscale.quantity) then dragonscale = dragonscale.quantity
	else dragonscale = 0 end
	if tuskarr.name and tonumber(tuskarr.quantity) then tuskarr = tuskarr.quantity
	else tuskarr = 0 end
	if centaur.name and tonumber(centaur.quantity) then centaur = centaur.quantity
	else centaur = 0 end
	if valdrakken.name and tonumber(valdrakken.quantity) then valdrakken = valdrakken.quantity
	else valdrakken = 0 end

	HUD:UpdateText(data, dragonscale .. "/" .. tuskarr .. "/" .. centaur .. "/" .. valdrakken)
end
------------------------------------------------

-- Ping
function Ns.FunctionList.Lag(HUD, data, options, ...)

	local EB, percentStat, ratingStat = options.World_Realm
	local _, _, lagRealm, lagWorld = GetNetStats()
	local lagColor = ""
	local returnText

	if lagWorld <= 90 or lagRealm <= 90 then lagColor = "|cff71FFC9"
	elseif (lagWorld >= 90 and lagWorld < 200) or  (lagRealm >= 90 and lagRealm < 200) then lagColor = "|cffFF7C0A"
	elseif lagWorld >= 200 or lagRealm >= 200 then lagColor = "|cffC41E3A" end
	
	if Ns.Band(EB, World) then returnText = lagColor .. floor(lagWorld) end
	if  Ns.Band(EB, Realm) then returnText = lagColor .. floor(lagRealm) end
	if  Ns.Band(EB, Both) then returnText = lagColor .. floor(lagWorld) .. "/" .. floor(lagRealm) end
	if returnText == nil then returnText = 0 end

	HUD:UpdateText(data, returnText)
end
------------------------------------------------

-- FPS
function Ns.FunctionList.FPS(HUD, data, options, ...)

	local framerate = GetFramerate()
	local fpsColor = ""
	
	if framerate < 30 then fpsColor = "|cffC41E3A"
	elseif framerate > 30 and framerate < 50 then fpsColor = "|cffFF7C0A"
	elseif framerate > 50 then fpsColor = "|cff71FFC9" end
	if returnText == nil then returnText = 0 end	
	
	HUD:UpdateText(data, fpsColor .. floor(framerate))
end
------------------------------------------------

-- Renown
function Ns.FunctionList.Renown(HUD, data, options, ...)

	local dragonscale = C_CurrencyInfo.GetCurrencyInfo(2021)
	local tuskarr = C_CurrencyInfo.GetCurrencyInfo(2087)
	local centaur = C_CurrencyInfo.GetCurrencyInfo(2002)
	local valdrakken = C_CurrencyInfo.GetCurrencyInfo(2088)
	local displayValdrakken, displayCentaur, displayTuskarr, displayDragonscale = "", "", "", ""

	if dragonscale.name and tonumber(dragonscale.quantity) then dragonscale = dragonscale.quantity; displayDragonscale = dragonscale
	else dragonscale = 0 end
	if tuskarr.name and tonumber(tuskarr.quantity) then tuskarr = tuskarr.quantity; displayTuskarr = "/" .. tuskarr
	else tuskarr = 0 end
	if centaur.name and tonumber(centaur.quantity) then centaur = centaur.quantity; displayCentaur = "/" .. centaur
	else centaur = 0 end
	if valdrakken.name and tonumber(valdrakken.quantity) then valdrakken = valdrakken.quantity; displayValdrakken = "/" .. valdrakken
	else valdrakken = 0 end
	
	if options.Hide_Reputation then
		if dragonscale == 25 then displayDragonscale = ""
		elseif tuskarr == 30 then displayTuskarr = ""
		elseif centaur == 25 then displayCentaur = ""
		elseif valdrakken == 30 then displayValdrakken = "" end
	end

	HUD:UpdateText(data, displayDragonscale .. displayTuskarr .. displayCentaur .. displayValdrakken)
end
------------------------------------------------

-- Mythic Plus rating
function Ns.FunctionList.MythicPlus(HUD, data, options, ...)

	local rating = C_MythicPlus.GetSeasonBestMythicRatingFromThisExpansion()
	local ratingColor = ""
	
	if rating >= 1000 and rating <= 1399 then ratingColor = Ns.greenText
	elseif rating >= 1400 and rating <= 1799 then ratingColor = Ns.blueText
	elseif rating >= 1800 and rating <= 2199 then ratingColor = Ns.purpleText
	elseif rating >= 2200 then ratingColor = Ns.orangeText
	else ratingColor = Ns.whiteText end
	

	HUD:UpdateText(data, ratingColor .. rating)
end
------------------------------------------------

-- Threat
function Ns.FunctionList.Threat(HUD, data, options, ...)

	local EB = options.Percent_Rating
	local _, _, threatpct, _, threatvalue = UnitDetailedThreatSituation("player", "target")
	local returnText
	local threatColor = ""

	if threatpct == nil then threatpct = 0 end
	if threatvalue == nil then threatvalue = 0 end	

	if threatpct <= 59 then threatColor = Ns.greenText
	elseif threatpct >= 60 and threatpct < 100 then threatColor = Ns.orangeText
	elseif threatpct == 100 then threatColor = Ns.redText end
	
	if Ns.Band(EB, Percentage) then returnText = threatColor .. ("%.0f%%"):format(threatpct) end
	if Ns.Band(EB, Rating) then returnText = threatColor .. ("%.0f"):format(threatvalue) end
	if Ns.Band(EB, Both) then returnText = threatColor .. ("%.0f%%"):format(threatpct) .. " |r(" .. ("%.0f"):format(threatvalue) .. ")" end		
	
	if returnText == nil then returnText = "" end
	
	HUD:UpdateText(data, returnText)
end
------------------------------------------------
